/*
 * Portions of this file Copyright 1999-2005 University of Chicago
 * Portions of this file Copyright 1999-2005 The University of Southern California.
 *
 * This file or a portion of this file is licensed under the
 * terms of the Globus Toolkit Public License, found at
 * http://www.globus.org/toolkit/download/license.html.
 * If you redistribute this file, with or without
 * modifications, you must include this notice in the file.
 */
 
package org.globus.transfer.reliable.service;

import java.util.Calendar;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class MyPerformanceLog {

    private long startTimestamp;
    private String taskName;
    private boolean enabled = false;
    private static Log logger = 
         LogFactory.getLog(MyPerformanceLog.class.getName());

    /**
    *  Constructor
    *  @param taskName name of the task which will be printed to the
    *         container logfile when the performance log will be stopped
    */
    public MyPerformanceLog(String taskName)
    {
        this.taskName = taskName;
    }
    
    /**
    *  Start the performance log. Time measurement begins from here.
    */
    public synchronized void start()
    {
        if (this.enabled) {
            logger.debug("PerformanceLog already started!");
            return;
        }
        this.enabled = true;
        startTimestamp = System.currentTimeMillis();
    }

    /**
    *  Stop the performance log. Time measurement stops here and
    *  information will be printed to the container logfile
    */    
    public synchronized void stop()
    {
        if (!enabled) {
            logger.debug("PerformanceLog not yet started!"+taskName);
            return;
        }

        long stopTimestamp = System.currentTimeMillis();

        logger.debug(
                "MY_PERFORMANCE_LOG" +
                "%%task=" + taskName +
                "%%duration=" + Long.toString(stopTimestamp - startTimestamp) +
                "%%startTime=" + formatStartDate());
        
        this.enabled=false;
    }

    /**
    *   Format the start date of the performance log
    */
    private String formatStartDate()
    {
      Calendar cal = Calendar.getInstance();
      cal.setTimeInMillis(startTimestamp);
      StringBuffer sb = new StringBuffer();
      sb.append(cal.get(Calendar.YEAR) + "-");
      int i = cal.get(Calendar.MONTH)+1;
      if (i<10) {
        sb.append("0");
      }
      sb.append(i+"-");
      i = cal.get(Calendar.DAY_OF_MONTH);
      if (i<10) {
        sb.append("0");
      }
      sb.append(i+" ");
      i = cal.get(Calendar.HOUR_OF_DAY);
      if (i<10) {
        sb.append("0");
      }
      sb.append(i+":");
      i = cal.get(Calendar.MINUTE);
      if (i<10) {
        sb.append("0");
      }
      sb.append(i+":");
      i = cal.get(Calendar.SECOND);
      if (i<10) {
        sb.append("0");
      }
      sb.append(i);

      return sb.toString();
    }

}
