/*
 * Portions of this file Copyright 1999-2005 University of Chicago
 * Portions of this file Copyright 1999-2005 The University of Southern California.
 *
 * This file or a portion of this file is licensed under the
 * terms of the Globus Toolkit Public License, found at
 * http://www.globus.org/toolkit/download/license.html.
 * If you redistribute this file, with or without
 * modifications, you must include this notice in the file.
 */
 
package org.globus.transfer.reliable.service;

import java.util.Map;
import java.util.HashMap;

public class MyPerformanceLogManager
{
   private Map perfLogs; 
   private static MyPerformanceLogManager INSTANCE = null;

   /**
   *  Hidden constructor
   */ 
   private MyPerformanceLogManager()
   {
      perfLogs = new HashMap();
   }

   /**
   * Get the single instance of MyPerformanceLogManager
   */
   public static synchronized MyPerformanceLogManager getInstance ()
   {
      if (INSTANCE==null) {
        INSTANCE = new MyPerformanceLogManager(); 
      }
      return INSTANCE;
   }
   
   /**
   *  Create a new performance log
   *  @param name identifier of the new performance log.
   *  @param text
   *         text that is displayed later, when the log stops
   *  @return true in case of successful creation, otherwise false
   */
   public boolean createPerformanceLog(String name, String text)
   {
       boolean successFlag = false;
       synchronized (perfLogs) {
           if (!perfLogs.containsKey(name)) {
               perfLogs.put(
                    name,
                    new MyPerformanceLog(text));
               successFlag = true;
           }
       }
       return successFlag;
   }

   /**
   *  Start an existing performance log
   *  @param name identifier of the performance log.
   *  @return true in case of successful start, otherwise false
   */
   public boolean startPerformanceLog(String name)
   {
       boolean successFlag = false;
       synchronized (perfLogs) {
           if (perfLogs.containsKey(name)) {
               ((MyPerformanceLog)perfLogs.get(name)).start();
               successFlag = true;
           }
       }
       return successFlag;
   }
   
   /**
   *  Stop and remove an existing performance log
   *  @param name identifier of the performance log.
   *  @return true in case of successful creation, otherwise false
   */
   public boolean stopPerformanceLog(String name)
   {
       boolean successFlag = false;
       MyPerformanceLog log = null;
       synchronized (perfLogs) {
           log = (MyPerformanceLog) perfLogs.remove(name);
       }
       if (log != null) {
           log.stop();
           successFlag = true;
       }
       return successFlag;
   }

}
